package lifeline.model;

import java.util.ArrayList;

import lifeline.connection.Connection;
import lifeline.connection.DBHandle;

import org.apache.http.HttpResponse;
import org.apache.http.message.BasicNameValuePair;

import android.content.Context;
import android.content.SharedPreferences;

public class Account {
	private static int id;
	private static User u;
	private static boolean authenticated = false;
	
	//This class is used to keep track of which user is logged in
	
	//checks with the server that the password is correct
	public synchronized static boolean authenticate(Context c, User u, String password) {
		if (password == null)
			return false;
		if (authenticated)
			return true;
		ArrayList<BasicNameValuePair> params = new ArrayList<BasicNameValuePair>();
		params.add(new BasicNameValuePair("id", String.valueOf(u.id())));
		params.add(new BasicNameValuePair("pass", password));
		HttpResponse resp = Connection.getRequest("/users/authenticate/" + u.id() + "/" + password);
		if (resp == null || resp.getStatusLine().getStatusCode() != 200)
			return false;
		id = u.id();
		Account.u = u;
		authenticated = true;
		SharedPreferences prefs = c.getSharedPreferences("lifeline", Context.MODE_PRIVATE);
		SharedPreferences.Editor ed = prefs.edit();
		ed.putString("Stored", String.valueOf(id));
		ed.commit();
		return true;
	}
	
	//if a user had authenticated on this machine before, this method will
	//set him as the current user
	public synchronized static boolean login() {
		if (authenticated)
			return true;
		Context c = DBHandle.getContext();
		SharedPreferences prefs = c.getSharedPreferences("lifeline", Context.MODE_PRIVATE);
		boolean stored = prefs.contains("Stored");
		if (stored) {
			String sid = prefs.getString("Stored", "-1");
			id = Integer.parseInt(sid);
			Account.u = User.find(id);
			if (Account.u == null) {
				logout();
				return false;
			}
			authenticated = true;
			return true;
		}
		return false;
	}
	
	//logs out the current user
	public synchronized static void logout() {
		Context c = DBHandle.getContext();
		SharedPreferences prefs = c.getSharedPreferences("lifeline", Context.MODE_PRIVATE);
		if (prefs.contains("Stored")) {
			SharedPreferences.Editor ed = prefs.edit();
			ed.remove("Stored");
			ed.commit();
		}
	}

	public synchronized static boolean authenticated() {
		return authenticated;
	}
	
	//returns the authenticated user's id
	public synchronized static int currId() {
		return id;
	}
	
	//returns the authenticated user
	public synchronized static User currUser() {
		return u;
	}
}
