package lifeline.model;

import java.util.ArrayList;

import lifeline.connection.Connection;
import lifeline.connection.DBHandle;

import org.apache.http.HttpResponse;
import org.apache.http.message.BasicNameValuePair;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;

// This class represents membership of a user in a given lifeline
public class Membership extends Model {
	private String user_id;
	private String group_id;
	public static String tableName = "memberships";

	Membership(User u, Group g) {
		super();
		user_id = String.valueOf(u._id);
		group_id = String.valueOf(g._id);
	}
	
	Membership(String userId, String groupId) {
		super();
		user_id = userId;
		group_id = groupId;
		tableName = "memberships";
	}

	//different from other models because it can only be created, never updated
	@Override
	protected boolean save() {
		ArrayList<BasicNameValuePair> params = toParams();
		return super.create(params);
	}

	@Override
	protected ContentValues toContentValues() {
		ContentValues v = new ContentValues();
		v.put("_id", _id);
		v.put("group_id", group_id);
		v.put("user_id", user_id);
		return v;
	}

	@Override
	protected ArrayList<BasicNameValuePair> toParams() {
		ArrayList<BasicNameValuePair> params = new ArrayList<BasicNameValuePair>();
		params.add(new BasicNameValuePair("user_id", user_id));
		params.add(new BasicNameValuePair("group_id", group_id));
		return params;
	}
	
	public static boolean fromServer(String id) {
		String path = "/" + tableName + "/" + id;
		HttpResponse resp = Connection.getRequest(path);
		if (resp == null || resp.getStatusLine().getStatusCode() != 200)
			return false;
		
		String user_id = resp.getHeaders("User_id")[0].getValue();
        String group_id = resp.getHeaders("Group_id")[0].getValue();
        Membership m = new Membership(user_id, group_id);
        m._id = Integer.parseInt(resp.getHeaders("Id")[0].getValue());
        m.globalSaved = true;
        
        return m.saveLocally();
	}
	
	public static boolean exists(String id) {
		SQLiteDatabase db = DBHandle.getConnection();
		String query = "SELECT * FROM " + tableName + " WHERE _id = ?";
		Cursor cur = db.rawQuery(query, new String[]{ id });
		boolean exists = (cur.getCount() == 1);
		cur.close();
		return exists;
	}
	
	public boolean saveLocally() {
		ContentValues v = toContentValues();
		v.put("_id", _id);
		long b = db.insert(tableName, null, v);
		if (b != _id)
			return false;
		return true;
	}
	
	@Override
	public String getTableName() {
		return tableName;
	}
}
