package lifeline.model;

import java.io.IOException;
import java.util.ArrayList;

import lifeline.connection.Connection;
import lifeline.connection.DBHandle;

import org.apache.http.HttpResponse;
import org.apache.http.message.BasicNameValuePair;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;

// This class represents a message sent to the application
public class Message extends Model {
	private String user_id;
	private String group_id;
	public String text;
	private String timestamp;
	public static String tableName = "messages";

	Message() {
		super();
	}
	Message(User u, Group g, String text) {
		this();
		globalSaved = false;
		user_id = String.valueOf(u._id);
		group_id = String.valueOf(g._id);
		this.text = text;
	}

	// different from the other models because it must also set the timestamp
	@Override
	protected boolean create(ArrayList<BasicNameValuePair> params) {
		HttpResponse resp = Connection.postRequest(params, "/" + tableName);
		int gid = -1;
		if (resp == null || resp.getStatusLine().getStatusCode() != 200)
			return false;
		gid = Integer.parseInt(resp.getHeaders("GID")[0].getValue());
		if (gid == -1)
			return false;
		_id = gid;
		timestamp = resp.getHeaders("Timestamp")[0].getValue();
		if (timestamp == null)
			return false;
		globalSaved = true;
		
		return saveLocally();
	}
	
	@Override
	protected ContentValues toContentValues() {
		ContentValues v = new ContentValues();
		v.put("group_id", group_id);
		v.put("text", text);
		v.put("timestamp", timestamp);
		v.put("user_id", user_id);
		return v;
	}

	@Override
	protected ArrayList<BasicNameValuePair> toParams() {
		ArrayList<BasicNameValuePair> params = new ArrayList<BasicNameValuePair>();
		params.add(new BasicNameValuePair("user_id", user_id));
		params.add(new BasicNameValuePair("group_id", group_id));
		params.add(new BasicNameValuePair("text", text));
		return params;
	}

	//given a cursor, returns a list of Groups it contains
	public static ArrayList<Message> fromCursor(Cursor cur) {
		ArrayList<Message> list = new ArrayList<Message>();
		if (cur.moveToFirst()) {
            do {
                // Get the field values
            	Message g = new Message();
            	g._id = Integer.valueOf(cur.getString(cur.getColumnIndex("_id")));
                g.user_id = cur.getString(cur.getColumnIndex("user_id"));
                g.group_id = cur.getString(cur.getColumnIndex("group_id"));
                g.text = cur.getString(cur.getColumnIndex("text"));
                g.timestamp = cur.getString(cur.getColumnIndex("timestamp"));
                g.globalSaved = true;
                list.add(g);
            } while (cur.moveToNext());
        }
		return list;
	}
	
	public static boolean fromServer(String id) {
		HttpResponse resp = Connection.getRequest("/" + tableName + "/" + id);
		if (resp == null || resp.getStatusLine().getStatusCode() != 200)
			return false;
		Message g = new Message();
		g._id = Integer.parseInt(resp.getHeaders("Id")[0].getValue());
		g.user_id = resp.getHeaders("User_id")[0].getValue();
        g.group_id = resp.getHeaders("Group_id")[0].getValue();
        try {
			g.text = resp.getEntity().getContent().toString();
		} catch (IllegalStateException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
        g.timestamp = resp.getHeaders("Timestamp")[0].getValue();
        g.globalSaved = true;
        
		return g.saveLocally();
	}
	
	public static boolean exists(String id) {
		SQLiteDatabase db = DBHandle.getConnection();
		String query = "SELECT * FROM " + tableName + " WHERE _id = ?";
		Cursor cur = db.rawQuery(query, new String[]{ id });
		boolean exists = (cur.getCount() == 1);
		cur.close();
		return exists;
	}
	
	public boolean saveLocally() {
		ContentValues v = toContentValues();
		v.put("_id", _id);
		long b = db.insert(tableName, null, v);
		if (b != _id)
			return false;
		return true;
	}
	
	@Override
	public String getTableName() {
		return tableName;
	}
	
	public String sender() {
		int uid = Integer.parseInt(user_id);
		User sender = User.find(uid);
		return sender.name;
	}
}
