package lifeline.model;

import java.util.ArrayList;

import lifeline.connection.Connection;
import lifeline.connection.DBHandle;

import org.apache.http.HttpResponse;
import org.apache.http.message.BasicNameValuePair;

import android.content.ContentValues;
import android.database.sqlite.SQLiteDatabase;

// Model is extended by all classes that have a corresponding database table name.
//it provides some common functionality they all share
public abstract class Model {
	protected int _id;
	protected SQLiteDatabase db;
	protected boolean globalSaved;

	public Model() {
		db = DBHandle.getConnection();
	}
	
	protected boolean save() {
		ArrayList<BasicNameValuePair> params = toParams();
		//if it has already been saved to the server, then update, otherwise,
		//create it, which involved saving it to the server
		if (globalSaved)
			return update(params);
		return create(params);
	}

	protected boolean create(ArrayList<BasicNameValuePair> params) {
		//send the model to the server to be saved
		HttpResponse resp = Connection.postRequest(params, "/" + getTableName());
		int gid = -1;
		if (resp == null || resp.getStatusLine().getStatusCode() != 200)
			return false;
		//the server's response, if successful, includes the object's global ID
		gid = Integer.parseInt(resp.getHeaders("GID")[0].getValue());
		if (gid == -1)
			return false;
		_id = gid;
		globalSaved = true;

		return saveLocally();
	}

	//each model subclass has its own DB table, this method returns that table's name
	public abstract String getTableName();

	//like create(), but for objects that had been previously created and now
	//are being modified
	protected boolean update(ArrayList<BasicNameValuePair> params) {
		HttpResponse resp = Connection.postRequest(params, "/" + getTableName() + "/" + _id);
		int gid = -1;
		if (resp == null || resp.getStatusLine().getStatusCode() != 200)
			return false;
		gid = Integer.parseInt(resp.getHeaders("GID")[0].getValue());
		if (gid == -1)
			return false;

		//save locally (omit saving _id)
		ContentValues v = toContentValues();
		long b = db.update(getTableName(), v, "_id =?", new String[]{Integer.toString(_id)});
		if (b != _id)
			return false;
		return true;
	}

	//returns a ContentValues with all the fields set, ready for storing in DB
	protected abstract ContentValues toContentValues();
	
	//returns an ArrayList with all fields set, ready for sending over the network
	protected abstract ArrayList<BasicNameValuePair> toParams();
	
	public int id() {
		return _id;
	}
	
	//saved the model to the phone's local SQLite DB
	protected abstract boolean saveLocally();
}
