package lifeline.model;

import java.util.ArrayList;

import lifeline.connection.Connection;
import lifeline.connection.DBHandle;

import org.apache.http.HttpResponse;
import org.apache.http.message.BasicNameValuePair;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;

// This class represents a user of the application
public class User extends Model {
	public String name;
	public String phone;
	public String email;
	public String twitter;
	private String pass;
	public static String tableName = "users";

	public User() {
		super();
		globalSaved = false;
	}

	public User(String name, String pass, String phone, String email,
			String twitter) {
		this.name = name;
		this.pass = pass;
		this.phone = phone;
		this.email = email;
		this.twitter = twitter;
		save();
	}
	
	@Override
	protected ArrayList<BasicNameValuePair> toParams(){
		if (email == null)
			email = "";
		if (twitter == null)
			twitter = "";
		ArrayList<BasicNameValuePair> params = new ArrayList<BasicNameValuePair>();
		params.add(new BasicNameValuePair("name",name));
		params.add(new BasicNameValuePair("phone", phone));
		params.add(new BasicNameValuePair("email", email));
		params.add(new BasicNameValuePair("twitter",twitter));
		params.add(new BasicNameValuePair("pass", pass));
		return params;
	}

	@Override
	protected ContentValues toContentValues() {
		ContentValues v = new ContentValues();
		v.put("email", email);
		v.put("name", name);
		v.put("phone", phone);
		v.put("twitter", twitter);
		v.put("pass", pass);
		return v;
	}
	
//  Use Group.addMember instead	
//	public boolean joinGroup(Group g) {
//		Membership m = new Membership(c, this, g);
//		return m.save();
//	}
	
	//given a cursor, returns a list of Users it contains
	public static ArrayList<User> fromCursor(Cursor cur) {
		ArrayList<User> list = new ArrayList<User>();
		if (cur.moveToFirst()) {
            do {
                // Get the field values
            	User u = new User();
            	String sid = cur.getString(cur.getColumnIndex("_id"));
            	u._id = Integer.valueOf(sid);
                u.name = cur.getString(cur.getColumnIndex("name"));
                u.phone = cur.getString(cur.getColumnIndex("phone"));
                u.email = cur.getString(cur.getColumnIndex("email"));
                u.twitter = cur.getString(cur.getColumnIndex("twitter"));
                u.pass = cur.getString(cur.getColumnIndex("pass"));
                u.globalSaved = true;
                list.add(u);
            } while (cur.moveToNext());
        }
		return list;
	}

	public ArrayList<Group> getLifelines() {
		String query = "SELECT g.* FROM groups g " +
		"INNER JOIN memberships m ON g._id = m.group_id " +
		"WHERE m.user_id = ?";
		Cursor cur = db.rawQuery(query, new String[]{String.valueOf(_id)});
		ArrayList<Group> list = Group.fromCursor(cur);
		cur.close();
		return list;
	}
	
	public static ArrayList<User> all() {
		SQLiteDatabase db = DBHandle.getConnection();
		Cursor cur = db.query("users", null, null, null, null, null, null);
		ArrayList<User> list = fromCursor(cur);
		cur.close();
		return list;
	}

	public static boolean fromServer(String id) {
		HttpResponse resp = Connection.getRequest("/" + tableName + "/" + id);
		if (resp == null || resp.getStatusLine().getStatusCode() != 200)
			return false;
		User u = new User();
		u._id = Integer.parseInt(resp.getHeaders("Id")[0].getValue());
		u.name = resp.getHeaders("Name")[0].getValue();
        u.twitter = resp.getHeaders("Twitter")[0].getValue();
        u.phone = resp.getHeaders("Phone")[0].getValue();
        u.email = resp.getHeaders("Email")[0].getValue();
        u.globalSaved = true;
        
        return u.saveLocally();
	}
	
	public static boolean exists(String id) {
		SQLiteDatabase db = DBHandle.getConnection();
		String query = "SELECT * FROM " + tableName + " WHERE _id = ?";
		Cursor cur = db.rawQuery(query, new String[]{ id });
		boolean exists = (cur.getCount() == 1);
		cur.close();
		return exists;
	}
	
	public static User find(int id) {
		String sid = String.valueOf(id);
		SQLiteDatabase db = DBHandle.getConnection();
		String query = "SELECT * FROM " + tableName + " WHERE _id = ?";
		Cursor cur = db.rawQuery(query, new String[]{ sid });
		ArrayList<User> found = fromCursor(cur);
		cur.close();
		if (found == null || found.size() == 0)
			return null;
		return found.get(0);
	}
	
	public static ArrayList<User> findByName(String name) {
		SQLiteDatabase db = DBHandle.getConnection();
		String query = "SELECT * FROM " + tableName + " WHERE name = ?";
		Cursor cur = db.rawQuery(query, new String[]{ name });
		ArrayList<User> found = fromCursor(cur);
		cur.close();
		return found;
	}
	
	public boolean saveLocally() {
		ContentValues v = toContentValues();
		v.put("_id", _id);
		long b = db.insert(tableName, null, v);
		if (b != _id)
			return false;
		return true;
	}
	
	@Override
	public String getTableName() {
		return tableName;
	}
	
	public static User currUser() {
		return Account.currUser();
	}
}
