package lifeline.ui;

import java.util.ArrayList;

import lifeline.connection.DBHandle;
import lifeline.model.Account;
import lifeline.model.Group;
import lifeline.model.User;
import lifeline.service.Updater;
import lifeline.service.UpdaterService;
import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;
import android.widget.AdapterView.OnItemClickListener;

public class Home extends Activity {
	private ListView lv;
	private User u;

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		//create the singleton handle to the local SQLite DB
		DBHandle.openConnection(this);
		
		//attempt to restore user session saved in Preference file, if available
		Account.login();

		//begin the updater service
		Intent serviceIntent = new Intent(this, UpdaterService.class);
		startService(serviceIntent);

		if(!Account.authenticated()){
			startActivity(new Intent(this, Login.class));
		} else {
			setContentView(R.layout.home);
			u = Account.currUser();
			lv = (ListView) findViewById(R.id.home_list);

			final ArrayList<Group> groupList = u.getLifelines();
			ArrayList<String> groupNames = new ArrayList<String>();
			for(Group group: groupList){
				groupNames.add(group.name);
			}

			lv.setAdapter(new ArrayAdapter<String>(this,  android.R.layout.simple_list_item_1, groupNames));

			lv.setOnItemClickListener(new OnItemClickListener() {
				public void onItemClick(AdapterView<?> parent, View view, int position, long id) {                    
					Intent intentLifelines = new Intent(getApplicationContext(), LifeLines.class);
					intentLifelines.putExtra("group_name", u.getLifelines().get(position).name);
					startActivity(intentLifelines);

					Toast.makeText(getApplicationContext(), 
							((TextView) view).getText(), Toast.LENGTH_SHORT).show();
				}
			});

			Button add = (Button) findViewById(R.id.home_add);
			add.setOnClickListener(new View.OnClickListener() {
				@Override
				public void onClick(View v) {
					Intent intentAddLifeline = new Intent(getApplicationContext(), AddLifeLine.class);
					Toast.makeText(getApplicationContext(), "Redirecting to the Add Lifeline Page", Toast.LENGTH_SHORT).show();
					startActivity(intentAddLifeline);
				}
			});
            
//            Button join = (Button) findViewById(R.id.home_join);
//            join.setOnClickListener(new View.OnClickListener() {
//				@Override
//				public void onClick(View v) {
//					Intent intentJoin = new Intent(getApplicationContext(), JoinLifelines.class);
//		    		Toast.makeText(getApplicationContext(), "Redirecting to the Join Lifelines Page", Toast.LENGTH_SHORT).show();
//		    		startActivity(intentJoin);
//				}
//			});
    	}
        
        // get current user lifelines() and store names to listIems
        // use a list adapter to display all of them make them clickable to the lifelines class
        // add item to temp.add("everything");
        // send an intent to load lifelines msgs 
    }
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
    	MenuInflater inflater = getMenuInflater();
    	inflater.inflate(R.menu.options_home, menu);
    	return true;
    }
    
    public boolean onOptionsItemSelected(MenuItem item) {
    	switch (item.getItemId()) {
    	case R.id.home_menu_lifeline:
    		Intent intentAddLifeline = new Intent(this, AddLifeLine.class);
    		//Toast.makeText(this, "Redirecting to the Add Lifeline Page", Toast.LENGTH_SHORT).show();
    		startActivity(intentAddLifeline);
    		return true;
    	case R.id.home_menu_logout:
    		Account.logout();
    		Toast.makeText(this, "GoodBye!", Toast.LENGTH_SHORT).show();
    		return true;
    	default:
    		return super.onOptionsItemSelected(item);
        }
    }
}
